@@ -31,7 +31,7 @@ class Region(BaseEnum):
     US = 1
     EU = 2
     KR = 3
-    CN = 5
+    # CN = 5
 
 
 class League(BaseEnum):
